@@ -1,5 +1,5 @@
 /*
- * iperf, Copyright (c) 2014-2021 The Regents of the University of
+ * iperf, Copyright (c) 2014-2022 The Regents of the University of
  * California, through Lawrence Berkeley National Laboratory (subject
  * to receipt of any required approvals from the U.S. Dept. of
  * Energy).  All rights reserved.
@@ -130,6 +130,16 @@ iperf_accept(struct iperf_test *test)
             return -1;
         }
 
+#if defined(HAVE_TCP_USER_TIMEOUT)
+        int opt;
+        if ((opt = test->settings->snd_timeout)) {
+            if (setsockopt(s, IPPROTO_TCP, TCP_USER_TIMEOUT, &opt, sizeof(opt)) < 0) {
+                i_errno = IESETUSERTIMEOUT;
+                return -1;
+            }
+        }
+#endif /* HAVE_TCP_USER_TIMEOUT */
+
         if (Nread(test->ctrl_sck, test->cookie, COOKIE_SIZE, Ptcp) < 0) {
             i_errno = IERECVCOOKIE;
             return -1;
@@ -141,14 +151,14 @@ iperf_accept(struct iperf_test *test)
             return -1;
         if (iperf_exchange_parameters(test) < 0)
             return -1;
-	if (test->server_affinity != -1) 
+	if (test->server_affinity != -1)
 	    if (iperf_setaffinity(test, test->server_affinity) != 0)
 		return -1;
         if (test->on_connect)
             test->on_connect(test);
     } else {
 	/*
-	 * Don't try to read from the socket.  It could block an ongoing test. 
+	 * Don't try to read from the socket.  It could block an ongoing test.
 	 * Just send ACCESS_DENIED.
          * Also, if sending failed, don't return an error, as the request is not related
          * to the ongoing test, and returning an error will terminate the test.
@@ -257,6 +267,7 @@ server_timer_proc(TimerClientData client_data, struct iperf_time *nowP)
         iperf_free_stream(sp);
     }
     close(test->ctrl_sck);
+    test->ctrl_sck = -1;
 }
 
 static void
@@ -325,7 +336,7 @@ create_server_timers(struct iperf_test * test)
 
 static void
 server_omit_timer_proc(TimerClientData client_data, struct iperf_time *nowP)
-{   
+{
     struct iperf_test *test = client_data.p;
 
     test->omit_timer = NULL;
@@ -345,7 +356,7 @@ static int
 create_server_omit_timer(struct iperf_test * test)
 {
     struct iperf_time now;
-    TimerClientData cd; 
+    TimerClientData cd;
 
     if (test->omit == 0) {
 	test->omit_timer = NULL;
@@ -353,11 +364,11 @@ create_server_omit_timer(struct iperf_test * test)
     } else {
 	if (iperf_time_now(&now) < 0) {
 	    i_errno = IEINITTEST;
-	    return -1; 
+	    return -1;
 	}
 	test->omitting = 1;
 	cd.p = test;
-	test->omit_timer = tmr_create(&now, server_omit_timer_proc, cd, test->omit * SEC_TO_US, 0); 
+	test->omit_timer = tmr_create(&now, server_omit_timer_proc, cd, test->omit * SEC_TO_US, 0);
 	if (test->omit_timer == NULL) {
 	    i_errno = IEINITTEST;
 	    return -1;
@@ -374,20 +385,26 @@ cleanup_server(struct iperf_test *test)
 
     /* Close open streams */
     SLIST_FOREACH(sp, &test->streams, streams) {
-	FD_CLR(sp->socket, &test->read_set);
-	FD_CLR(sp->socket, &test->write_set);
-	close(sp->socket);
+	if (sp->socket > -1) {
+            FD_CLR(sp->socket, &test->read_set);
+            FD_CLR(sp->socket, &test->write_set);
+            close(sp->socket);
+            sp->socket = -1;
+	}
     }
 
     /* Close open test sockets */
-    if (test->ctrl_sck) {
+    if (test->ctrl_sck > -1) {
 	close(test->ctrl_sck);
+        test->ctrl_sck = -1;
     }
-    if (test->listener) {
+    if (test->listener > -1) {
 	close(test->listener);
+        test->listener = -1;
     }
     if (test->prot_listener > -1) {     // May remain open if create socket failed
 	close(test->prot_listener);
+        test->prot_listener = -1;
     }
 
     /* Cancel any remaining timers. */
@@ -437,15 +454,19 @@ iperf_run_server(struct iperf_test *test)
 
     if (test->logfile)
         if (iperf_open_logfile(test) < 0)
-            return -1;
+            return -2;
 
-    if (test->affinity != -1) 
-	if (iperf_setaffinity(test, test->affinity) != 0)
+    if (test->affinity != -1)
+	if (iperf_setaffinity(test, test->affinity) != 0) {
+            cleanup_server(test);
 	    return -2;
+        }
 
     if (test->json_output)
-	if (iperf_json_start(test) < 0)
+	if (iperf_json_start(test) < 0) {
+            cleanup_server(test);
 	    return -2;
+        }
 
     if (test->json_output) {
 	cJSON_AddItemToObject(test->json_start, "version", cJSON_CreateString(version));
@@ -459,6 +480,7 @@ iperf_run_server(struct iperf_test *test)
 
     // Open socket and listen
     if (iperf_server_listen(test) < 0) {
+	cleanup_server(test);
         return -2;
     }
 
@@ -475,7 +497,7 @@ iperf_run_server(struct iperf_test *test)
 	if (test->bitrate_limit_exceeded) {
 	    cleanup_server(test);
             i_errno = IETOTALRATE;
-            return -1;	
+            return -1;
 	}
 
         memcpy(&read_set, &test->read_set, sizeof(fd_set));
@@ -525,6 +547,13 @@ iperf_run_server(struct iperf_test *test)
                             printf("Server restart (#%d) in idle state as no connection request was received for %d sec\n",
                                 test->server_forced_idle_restarts_count, test->settings->idle_timeout);
                         cleanup_server(test);
+			if ( iperf_get_test_one_off(test) ) {
+			  if (test->debug)
+                            printf("No connection request was received for %d sec in one-off mode; exiting.\n",
+				   test->settings->idle_timeout);
+			  exit(0);
+			}
+
                         return 2;
                     }
                 }
@@ -532,7 +561,7 @@ iperf_run_server(struct iperf_test *test)
                     test->server_forced_no_msg_restarts_count += 1;
                     i_errno = IENOMSG;
                     if (iperf_get_verbose(test))
-                        iperf_err(test, "Server restart (#%d) during active test due to idle data for receiving data",
+                        iperf_err(test, "Server restart (#%d) during active test due to idle timeout for receiving data",
                                   test->server_forced_no_msg_restarts_count);
                     cleanup_server(test);
                     return -1;
@@ -569,19 +598,42 @@ iperf_run_server(struct iperf_test *test)
 		    cleanup_server(test);
                     return -1;
 		}
-                FD_CLR(test->ctrl_sck, &read_set);                
+                FD_CLR(test->ctrl_sck, &read_set);
             }
 
             if (test->state == CREATE_STREAMS) {
                 if (FD_ISSET(test->prot_listener, &read_set)) {
-    
+
                     if ((s = test->protocol->accept(test)) < 0) {
 			cleanup_server(test);
                         return -1;
 		    }
 
+		    /* apply other common socket options */
+                    if (iperf_common_sockopts(test, s) < 0)
+                    {
+                        cleanup_server(test);
+                        return -1;
+                    }
+
                     if (!is_closed(s)) {
 
+#if defined(HAVE_TCP_USER_TIMEOUT)
+		    if (test->protocol->id == Ptcp) {
+                        int opt;
+                        if ((opt = test->settings->snd_timeout)) {
+                            if (setsockopt(s, IPPROTO_TCP, TCP_USER_TIMEOUT, &opt, sizeof(opt)) < 0) {
+                                saved_errno = errno;
+                                close(s);
+                                cleanup_server(test);
+                                errno = saved_errno;
+                                i_errno = IESETUSERTIMEOUT;
+                                return -1;
+                            }
+                        }
+                    }
+#endif /* HAVE_TCP_USER_TIMEOUT */
+
 #if defined(HAVE_TCP_CONGESTION)
 		    if (test->protocol->id == Ptcp) {
 			if (test->congestion) {
@@ -606,7 +658,7 @@ iperf_run_server(struct iperf_test *test)
 				    i_errno = IESETCONGESTION;
 				    return -1;
 				}
-			    } 
+			    }
 			}
 			{
 			    socklen_t len = TCP_CA_NAME_MAX;
@@ -621,7 +673,7 @@ iperf_run_server(struct iperf_test *test)
 				i_errno = IESETCONGESTION;
 				return -1;
 			    }
-                            /* 
+                            /*
                              * If not the first connection, discard prior
                              * congestion algorithm name so we don't leak
                              * duplicated strings.  We probably don't need
@@ -689,11 +741,12 @@ iperf_run_server(struct iperf_test *test)
                     if (test->protocol->id != Ptcp) {
                         FD_CLR(test->prot_listener, &test->read_set);
                         close(test->prot_listener);
-                    } else { 
+                        test->prot_listener = -1;
+                    } else {
                         if (test->no_delay || test->settings->mss || test->settings->socket_bufsize) {
                             FD_CLR(test->listener, &test->read_set);
                             close(test->listener);
-			    test->listener = 0;
+			    test->listener = -1;
                             if ((s = netannounce(test->settings->domain, Ptcp, test->bind_address, test->bind_dev, test->server_port)) < 0) {
 				cleanup_server(test);
                                 i_errno = IELISTEN;
@@ -782,16 +835,16 @@ iperf_run_server(struct iperf_test *test)
 	}
     }
 
-    cleanup_server(test);
 
     if (test->json_output) {
 	if (iperf_json_finish(test) < 0)
 	    return -1;
-    } 
+    }
 
     iflush(test);
+    cleanup_server(test);
 
-    if (test->server_affinity != -1) 
+    if (test->server_affinity != -1)
 	if (iperf_clearaffinity(test) != 0)
 	    return -1;
 
