@@ -1,5 +1,5 @@
 /*
- * iperf, Copyright (c) 2014-2023, The Regents of the University of
+ * iperf, Copyright (c) 2014-2022, The Regents of the University of
  * California, through Lawrence Berkeley National Laboratory (subject
  * to receipt of any required approvals from the U.S. Dept. of
  * Energy).  All rights reserved.
@@ -33,7 +33,9 @@
 #include <errno.h>
 #include <signal.h>
 #include <unistd.h>
+#ifdef HAVE_STDINT_H
 #include <stdint.h>
+#endif
 #include <sys/socket.h>
 #include <sys/types.h>
 #include <netinet/in.h>
@@ -57,24 +59,6 @@ main(int argc, char **argv)
 {
     struct iperf_test *test;
 
-    /*
-     * Atomics check. We prefer to have atomic types (which is
-     * basically on any compiler supporting C11 or better). If we
-     * don't have them, we try to approximate the type we need with a
-     * regular integer, but complain if they're not lock-free. We only
-     * know how to check this on GCC. GCC on CentOS 7 / RHEL 7 is the
-     * targeted use case for these check.
-     */
-#ifndef HAVE_STDATOMIC_H
-#ifdef __GNUC__
-    if (! __atomic_always_lock_free (sizeof (u_int64_t), 0)) {
-#endif // __GNUC__
-        fprintf(stderr, "Warning: Cannot guarantee lock-free operation with 64-bit data types\n");
-#ifdef __GNUC__
-    }
-#endif // __GNUC__
-#endif // HAVE_STDATOMIC_H
-
     // XXX: Setting the process affinity requires root on most systems.
     //      Is this a feature we really need?
 #ifdef TEST_PROC_AFFINITY
@@ -117,7 +101,7 @@ main(int argc, char **argv)
     if (iperf_parse_arguments(test, argc, argv) < 0) {
         iperf_err(test, "parameter error - %s", iperf_strerror(i_errno));
         fprintf(stderr, "\n");
-        usage();
+        usage_long(stdout);
         exit(1);
     }
 
@@ -131,12 +115,10 @@ main(int argc, char **argv)
 
 
 static jmp_buf sigend_jmp_buf;
-static int signed_sig;
 
 static void __attribute__ ((noreturn))
 sigend_handler(int sig)
 {
-    signed_sig = sig;
     longjmp(sigend_jmp_buf, 1);
 }
 
@@ -147,7 +129,7 @@ run(struct iperf_test *test)
     /* Termination signals. */
     iperf_catch_sigend(sigend_handler);
     if (setjmp(sigend_jmp_buf))
-	iperf_got_sigend(test, signed_sig);
+	iperf_got_sigend(test);
 
     /* Ignore SIGPIPE to simplify error handling */
     signal(SIGPIPE, SIG_IGN);
@@ -156,7 +138,7 @@ run(struct iperf_test *test)
         case 's':
 	    if (test->daemon) {
 		int rc;
-		rc = daemon(1, 0);
+		rc = daemon(0, 0);
 		if (rc < 0) {
 		    i_errno = IEDAEMON;
 		    iperf_errexit(test, "error - %s", iperf_strerror(i_errno));
